import { DynamicFormControlComponent, DynamicFormControlComponentBase, DynamicFormErrorComponent, DynamicFormFormControlComponent, DynamicForm, DynamicFormService, ControlType, DynamicFormModule } from '@angular-dynaform/core';
import { CommonModule } from '@angular/common';
import { Component, ElementRef, ViewChild, EventEmitter, NgModule, Optional, SkipSelf } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { MatButtonModule, MatCheckboxModule, MatInputModule, MatRadioModule, MatSelectModule, MatSliderModule, MatSlideToggleModule, MatNativeDateModule, MatDatepickerModule, MatTabsModule, MatStepperModule, MatIconModule } from '@angular/material';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { map, takeUntil } from 'rxjs/operators';
import { Subject } from 'rxjs';

class MaterialArrayComponent extends DynamicFormControlComponent {
}
MaterialArrayComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-array-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <fieldset [id]="model.id" [ngClass]="model.css.control" adfHTMLDomElement>
        <legend
          *ngIf="model.local.label"
          [ngClass]="model.css.label"
          [innerHTML]="model.local.label"
        ></legend>
        <ng-container *ngIf="model.header">
          <div [ngClass]="model.header?.css.content">
            <ng-container
              *ngFor="let item of model.header?.items"
              adfControlComponent
              [model]="item"
            ></ng-container>
          </div>
        </ng-container>
        <adf-error-container [model]="model"></adf-error-container>
        <div [formArrayName]="model.key" [ngClass]="model.css.content">
          <ng-container *ngFor="let arrayItem of model.items; let i = index" [formGroupName]="i">
            <div [ngClass]="arrayItem.css.content">
              <ng-container
                *ngFor="let item of arrayItem.items"
                adfControlComponent
                [model]="item"
              ></ng-container>
            </div>
          </ng-container>
        </div>
        <ng-container *ngIf="model.footer">
          <div [ngClass]="model.footer?.css.content">
            <ng-container
              *ngFor="let item of model.footer?.items"
              adfControlComponent
              [model]="item"
            ></ng-container>
          </div>
        </ng-container>
      </fieldset>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialArrayComponent }]
            }] }
];

class MaterialButtonComponent extends DynamicFormControlComponent {
    ngAfterViewInit() {
        super.ngAfterViewInit();
        setTimeout((() => {
            if (this.model.ngControl.disabled) {
                this.model.ngControl.enable({ emitEvent: false });
                this.model.ngControl.disable();
            }
            else {
                this.model.ngControl.disable({ emitEvent: false });
                this.model.ngControl.enable();
            }
        }));
    }
}
MaterialButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-button-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <button
        mat-raised-button
        [formControlName]="model.key"
        [id]="model.id"
        [ngClass]="model.css.control"
        [type]="buttonType"
        adfHTMLDomElement
        ngDefaultControl
      >
        <span [ngClass]="model.css.control" [innerHTML]="model.local.label"></span>
      </button>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialButtonComponent }]
            }] }
];

class MaterialCheckboxComponent extends DynamicFormControlComponent {
}
MaterialCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-checkbox-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <mat-checkbox
        [formControlName]="model.key"
        [id]="model.id"
        [ngClass]="model.css.control"
        adfHTMLDomElement
        [required]="options.required ? '' : null"
      >
        {{ model.local.label }}
      </mat-checkbox>
      <adf-error-container [model]="model"></adf-error-container>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialCheckboxComponent }]
            }] }
];

class MaterialDatepickerComponent extends DynamicFormControlComponent {
}
MaterialDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-datepicker-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-form-field [ngClass]="model.css.control">
        <input
          matInput
          [formControlName]="model.key"
          [id]="model.id"
          type="text"
          [readonly]="options.readOnly"
          [maxlength]="options.maxLength"
          [placeholder]="model.local.placeholder"
          [ngClass]="model.css.control"
          adfHTMLDomElement
          [matDatepicker]="myDatepicker"
          [required]="options.required ? '' : null"
        />
        <mat-datepicker-toggle matSuffix [for]="myDatepicker"></mat-datepicker-toggle>
        <mat-datepicker #myDatepicker></mat-datepicker>
        <span matPrefix *ngIf="options.icon">
          <mat-icon>{{ options.icon }}</mat-icon>
        </span>
        <adf-error-container [model]="model"></adf-error-container>
        <mat-hint [innerHTML]="model.local.hint"></mat-hint>
      </mat-form-field>
    </div>
  `,
                inputs: ['model'],
                providers: [
                    { provide: DynamicFormControlComponentBase, useExisting: MaterialDatepickerComponent },
                ]
            }] }
];

class MaterialDivisionComponent extends DynamicFormControlComponent {
}
MaterialDivisionComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-division-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <div [ngClass]="model.css.control" adfHTMLDomElement>
        <adf-error-container [model]="model"></adf-error-container>
        <div [ngClass]="model.css.content">
          <ng-container
            *ngFor="let item of model.items"
            adfControlComponent
            [model]="item"
          ></ng-container>
        </div>
      </div>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialDivisionComponent }]
            }] }
];

class MaterialErrorComponent extends DynamicFormErrorComponent {
}
MaterialErrorComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-error-component',
                template: `
    <mat-error [ngClass]="model.css.error" [innerHTML]="error?.message"></mat-error>
  `,
                inputs: ['model', 'error'],
                host: { class: 'mat-input-error' },
                providers: [{ provide: DynamicFormErrorComponent, useExisting: MaterialErrorComponent }]
            }] }
];

class MaterialFieldsetComponent extends DynamicFormControlComponent {
}
MaterialFieldsetComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-fieldset-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <fieldset [id]="model.id" [ngClass]="model.css.control" adfHTMLDomElement>
        <legend
          *ngIf="model.local.label"
          [ngClass]="model.css.label"
          [innerHTML]="model.local.label"
        ></legend>
        <adf-error-container [model]="model"></adf-error-container>
        <div [ngClass]="model.css.content">
          <ng-container
            *ngFor="let item of model.items"
            adfControlComponent
            [model]="item"
          ></ng-container>
        </div>
      </fieldset>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialFieldsetComponent }]
            }] }
];

class MaterialFormComponent extends DynamicFormFormControlComponent {
}
MaterialFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-form-component',
                template: `
    <div>
      <form
        [formGroup]="model.ngControl"
        [id]="model.id"
        [ngClass]="model.css.control"
        (ngSubmit)="onSubmit($event)"
        (reset)="onReset($event)"
        adfHTMLDomElement
        novalidate
      >
        <div [ngClass]="model.css.content">
          <ng-container
            *ngFor="let item of model.items"
            adfControlComponent
            [model]="item"
          ></ng-container>
        </div>
      </form>
    </div>
  `,
                inputs: ['model'],
                outputs: ['submit', 'reset'],
                providers: [
                    {
                        provide: DynamicFormControlComponentBase,
                        useExisting: MaterialFormComponent,
                    },
                    { provide: DynamicFormFormControlComponent, useExisting: MaterialFormComponent },
                ]
            }] }
];

class MaterialInputComponent extends DynamicFormControlComponent {
}
MaterialInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-input-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-form-field [ngClass]="model.css.control">
        <input
          matInput
          [formControlName]="model.key"
          [id]="model.id"
          [type]="options.inputType || 'text'"
          [readonly]="options.readOnly"
          [attr.autocomplete]="model.autoComplete"
          [placeholder]="model.local.placeholder"
          [ngClass]="model.css.control"
          adfHTMLDomElement
          [required]="options.required ? '' : null"
          [attr.min]="options.min"
          [attr.max]="options.max"
          [maxlength]="options.maxLength"
        />
        <span matPrefix *ngIf="options.icon">
          <mat-icon>{{ options.icon }}</mat-icon>
        </span>
        <adf-error-container [model]="model"></adf-error-container>
        <mat-hint [innerHTML]="model.local.hint"></mat-hint>
      </mat-form-field>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialInputComponent }]
            }] }
];

class MaterialRadioGroupComponent extends DynamicFormControlComponent {
}
MaterialRadioGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-radiogroup-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-radio-group
        [id]="model.id"
        [formControlName]="model.key"
        ngDefaultControl
        adfHTMLDomElement
        [ngClass]="model.css.control"
        [required]="options.required ? '' : null"
      >
        <mat-radio-button *ngFor="let opt of model.local.valueOptions" [value]="opt.value">
          <span [innerHTML]="opt.label"></span>
        </mat-radio-button>
      </mat-radio-group>
      <adf-error-container [model]="model"></adf-error-container>
    </div>
  `,
                inputs: ['model'],
                providers: [
                    { provide: DynamicFormControlComponentBase, useExisting: MaterialRadioGroupComponent },
                ]
            }] }
];

class MaterialSelectComponent extends DynamicFormControlComponent {
}
MaterialSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-select-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-form-field [ngClass]="model.css.control">
        <mat-select
          [formControlName]="model.key"
          [id]="model.id"
          [placeholder]="model.local.placeholder"
          [multiple]="options.multiple"
          [ngClass]="model.css.control"
          adfHTMLDomElement
          [required]="options.required ? '' : null"
        >
          <mat-option *ngFor="let opt of model.local.valueOptions" [value]="opt.value">
            <span [innerHTML]="opt.label"></span>
          </mat-option>
        </mat-select>
        <span matPrefix *ngIf="options.icon">
          <mat-icon>{{ options.icon }}</mat-icon>
        </span>
        <adf-error-container [model]="model"></adf-error-container>
        <mat-hint [innerHTML]="model.local.hint"></mat-hint>
      </mat-form-field>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialSelectComponent }]
            }] }
];

class MaterialSeparatorComponent extends DynamicFormControlComponent {
}
MaterialSeparatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-separator-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <span [ngClass]="model.css.control" [innerHTML]="model.local.label"></span>
    </div>
  `,
                inputs: ['model'],
                providers: [
                    { provide: DynamicFormControlComponentBase, useExisting: MaterialSeparatorComponent },
                ]
            }] }
];

class MaterialSliderComponent extends DynamicFormControlComponent {
}
MaterialSliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-slider-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-slider
        [formControlName]="model.key"
        [id]="model.id"
        [step]="options.step"
        [ngClass]="model.css.control"
        adfHTMLDomElement
        [required]="options.required ? '' : null"
        [attr.min]="options.min"
        [attr.max]="options.max"
      ></mat-slider>
      <adf-error-container [model]="model"></adf-error-container>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialSliderComponent }]
            }] }
];

class MaterialStepperComponent extends DynamicFormControlComponent {
    constructor(form, dynamicFormService, elRef) {
        super(form, dynamicFormService, elRef);
    }
    ngOnInit() {
        this.stepper = new MatStepperWrapper(this.matStepper);
        if (!this.form.stepper) {
            this.form.stepper = this.stepper;
        }
        super.ngOnInit();
    }
    ngAfterViewInit() {
        (((this.stepper))).matStepper = this.matStepper;
        super.ngAfterViewInit();
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        if (this.stepper) {
            if (this.form.stepper === this.stepper) {
                this.form.stepper = undefined;
            }
            (((this.stepper))).matStepper = undefined;
        }
    }
}
MaterialStepperComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-stepper-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <div [ngClass]="model.css.control" adfHTMLDomElement>
        <adf-error-container [model]="model"></adf-error-container>

        <!--ng-template #steps>
            <mat-step *ngFor="let item of model.items; let i=index"
              [stepControl]="item.ngSubsetControl ? item.ngSubsetControl : item.ngControl"
              [optional]="options.matStepOptional" [editable]="options.matStepEditable" [completed]="options.matStepCompleted"
            >
              <ng-template matStepLabel>{{item.local.label}}</ng-template>
              <ng-template adfControlComponent [model]="item"></ng-template>
            </mat-step>
        </ng-template-->

        <ng-container *ngIf="options.matStepperVertical; else horizontalStepper">
          <mat-vertical-stepper
            [ngClass]="model.css.content"
            [linear]="options.matStepperLinear === undefined ? false : options.matStepperLinear"
            #stepper
          >
            <!--ng-container *ngTemplateOutlet="steps"></ng-container-->
            <mat-step
              *ngFor="let item of model.items; let i = index"
              [stepControl]="item.ngSubsetControl ? item.ngSubsetControl : item.ngControl"
              [editable]="options.matStepEditable === undefined ? true : options.matStepEditable"
              [optional]="options.matStepOptional"
              [completed]="options.matStepCompleted"
            >
              <ng-template matStepLabel>{{ item.local.label }}</ng-template>
              <ng-template adfControlComponent [model]="item"></ng-template>
            </mat-step>
          </mat-vertical-stepper>
        </ng-container>

        <ng-template #horizontalStepper>
          <mat-horizontal-stepper
            [ngClass]="model.css.content"
            [linear]="options.matStepperLinear === undefined ? false : options.matStepperLinear"
            #stepper
          >
            <!--ng-container *ngTemplateOutlet="steps"></ng-container-->
            <mat-step
              *ngFor="let item of model.items; let i = index"
              [stepControl]="item.ngSubsetControl ? item.ngSubsetControl : item.ngControl"
              [editable]="options.matStepEditable === undefined ? true : options.matStepEditable"
              [optional]="options.matStepOptional"
              [completed]="options.matStepCompleted"
            >
              <ng-template matStepLabel>{{ item.local.label }}</ng-template>
              <ng-template adfControlComponent [model]="item"></ng-template>
            </mat-step>
          </mat-horizontal-stepper>
        </ng-template>
      </div>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialStepperComponent }]
            }] }
];
MaterialStepperComponent.ctorParameters = () => [
    { type: DynamicForm },
    { type: DynamicFormService },
    { type: ElementRef }
];
MaterialStepperComponent.propDecorators = {
    matStepper: [{ type: ViewChild, args: ['stepper', { static: true },] }]
};
class MatStepperWrapper {
    get matStepper() {
        return this._matStepper;
    }
    set matStepper(matStepper) {
        this.changeStepper(matStepper);
    }
    constructor(matStepper) {
        this._selectionChange = new EventEmitter();
        this.matStepper = matStepper;
    }
    prev() {
        if (this.matStepper) {
            this.matStepper.previous();
        }
    }
    next() {
        if (this.matStepper) {
            this.matStepper.next();
        }
    }
    selectionChange() {
        return this._selectionChange;
    }
    length() {
        return this.matStepper && this.matStepper._steps ? this.matStepper._steps.length : 0;
    }
    changeStepper(matStepper) {
        if (this._matStepper === matStepper) {
            return;
        }
        if (this._matStepper && this.unsubscribe) {
            this.unsubscribe.next();
            this.unsubscribe.complete();
        }
        if (matStepper) {
            this.unsubscribe = new Subject();
            matStepper.selectionChange
                .pipe(map(((sc) => sc.selectedIndex)))
                .pipe(takeUntil(this.unsubscribe))
                .subscribe(((currIndex) => this._selectionChange.emit(currIndex)));
        }
        this._matStepper = matStepper;
    }
}

class MaterialSwitchComponent extends DynamicFormControlComponent {
}
MaterialSwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-switch-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-slide-toggle
        [formControlName]="model.key"
        [id]="model.id"
        [ngClass]="model.css.control"
        adfHTMLDomElement
        [required]="options.required ? '' : null"
      ></mat-slide-toggle>
      <adf-error-container [model]="model"></adf-error-container>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialSwitchComponent }]
            }] }
];

class MaterialTabGroupComponent extends DynamicFormControlComponent {
}
MaterialTabGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-tab-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <div [ngClass]="model.css.control" adfHTMLDomElement>
        <adf-error-container [model]="model"></adf-error-container>
        <mat-tab-group
          adfHTMLDomElement
          [ngClass]="model.css.content"
          [dynamicHeight]="options.matTabGroupDynamicHeight"
        >
          <mat-tab *ngFor="let item of model.items">
            <ng-template mat-tab-label>{{ item.local.label }}</ng-template>
            <ng-template adfControlComponent [model]="item"></ng-template>
          </mat-tab>
        </mat-tab-group>
      </div>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialTabGroupComponent }]
            }] }
];

class MaterialTextareaComponent extends DynamicFormControlComponent {
}
MaterialTextareaComponent.decorators = [
    { type: Component, args: [{
                selector: 'adf-material-textarea-component',
                template: `
    <div [formGroup]="model.ngGroup" [hidden]="model.hidden">
      <label
        *ngIf="model.local.label"
        [attr.for]="model.id"
        class="adf-front-label"
        [ngClass]="model.css.label"
        [innerHTML]="model.local.label"
      ></label>
      <mat-form-field [ngClass]="model.css.control">
        <textarea
          matInput
          [formControlName]="model.key"
          [id]="model.id"
          [readonly]="options.readOnly"
          [wrap]="options.wrap"
          [cols]="options.cols"
          [rows]="options.rows"
          [placeholder]="model.local.placeholder"
          [ngClass]="model.css.control"
          adfHTMLDomElement
          [required]="options.required ? '' : null"
          [attr.min]="options.min"
          [attr.max]="options.max"
          [maxlength]="options.maxLength"
        ></textarea>
        <span matPrefix *ngIf="options.icon">
          <mat-icon>{{ options.icon }}</mat-icon>
        </span>
        <adf-error-container [model]="model"></adf-error-container>
        <mat-hint [innerHTML]="model.local.hint"></mat-hint>
      </mat-form-field>
    </div>
  `,
                inputs: ['model'],
                providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialTextareaComponent }]
            }] }
];

const MaterialControlType = {
    CONTROL_UNKNOWN: 'mat:unknown',
    CONTROL_DIVISION: 'mat:division',
    CONTROL_FIELDSET: 'mat:fieldset',
    CONTROL_TABGROUP: 'mat:tabgroup',
    CONTROL_STEPPER: 'mat:stepper',
    CONTROL_ARRAY: 'mat:array',
    CONTROL_CHECKBOX: 'mat:checkbox',
    CONTROL_INPUT: 'mat:input',
    CONTROL_RADIOGROUP: 'mat:radiogroup',
    CONTROL_SELECT: 'mat:select',
    CONTROL_SLIDER: 'mat:slider',
    CONTROL_SWITCH: 'mat:switch',
    CONTROL_TEXTAREA: 'mat:textarea',
    CONTROL_DATEPICKER: 'mat:datepicker',
    CONTROL_TIMEPICKER: 'mat:timepicker',
    CONTROL_LISTPICKER: 'mat:listpicker',
    CONTROL_UPLOAD: 'mat:upload',
    CONTROL_BUTTON: 'mat:button',
    CONTROL_SEPARATOR: 'mat:separator',
};

const entryComponents = [
    MaterialFormComponent,
    MaterialErrorComponent,
    MaterialArrayComponent,
    MaterialDivisionComponent,
    MaterialFieldsetComponent,
    MaterialButtonComponent,
    MaterialCheckboxComponent,
    MaterialInputComponent,
    MaterialRadioGroupComponent,
    MaterialSelectComponent,
    MaterialSeparatorComponent,
    MaterialSliderComponent,
    MaterialSwitchComponent,
    MaterialTextareaComponent,
    MaterialDatepickerComponent,
    MaterialTabGroupComponent,
    MaterialStepperComponent,
];
const moduleDeclarations = entryComponents;
class DynamicMaterialFormModule {
    constructor(dynamicFormService, parentModule) {
        this.dynamicFormService = dynamicFormService;
        if (parentModule) {
            return;
        }
        this.dynamicFormService.setFormControlComponent(MaterialFormComponent, true);
        this.dynamicFormService.setErrorComponent(MaterialErrorComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_ARRAY, MaterialArrayComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_FIELDSET, MaterialFieldsetComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_DIVISION, MaterialDivisionComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_TABGROUP, MaterialTabGroupComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_STEPPER, MaterialStepperComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_BUTTON, MaterialButtonComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SEPARATOR, MaterialSeparatorComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_CHECKBOX, MaterialCheckboxComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_DATEPICKER, MaterialDatepickerComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_INPUT, MaterialInputComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_RADIOGROUP, MaterialRadioGroupComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SELECT, MaterialSelectComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SLIDER, MaterialSliderComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SWITCH, MaterialSwitchComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_TEXTAREA, MaterialTextareaComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_ARRAY, MaterialArrayComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_FIELDSET, MaterialFieldsetComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_DIVISION, MaterialDivisionComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_TABGROUP, MaterialTabGroupComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_STEPPER, MaterialStepperComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_BUTTON, MaterialButtonComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SEPARATOR, MaterialSeparatorComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_CHECKBOX, MaterialCheckboxComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_DATEPICKER, MaterialDatepickerComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_INPUT, MaterialInputComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_RADIOGROUP, MaterialRadioGroupComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SELECT, MaterialSelectComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SLIDER, MaterialSliderComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SWITCH, MaterialSwitchComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_TEXTAREA, MaterialTextareaComponent, true);
    }
}
DynamicMaterialFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    DynamicFormModule,
                    BrowserAnimationsModule,
                    MatButtonModule,
                    MatCheckboxModule,
                    MatInputModule,
                    MatRadioModule,
                    MatSelectModule,
                    MatSliderModule,
                    MatSlideToggleModule,
                    MatNativeDateModule,
                    MatDatepickerModule,
                    MatTabsModule,
                    MatStepperModule,
                    MatIconModule,
                ],
                declarations: [moduleDeclarations],
                entryComponents,
                exports: [DynamicFormModule, entryComponents],
            },] }
];
DynamicMaterialFormModule.ctorParameters = () => [
    { type: DynamicFormService },
    { type: DynamicMaterialFormModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

export { DynamicMaterialFormModule, MaterialArrayComponent, MaterialButtonComponent, MaterialCheckboxComponent, MaterialControlType, MaterialDivisionComponent, MaterialErrorComponent, MaterialFieldsetComponent, MaterialFormComponent, MaterialInputComponent, MaterialRadioGroupComponent, MaterialSelectComponent, MaterialSeparatorComponent, MaterialSliderComponent, MaterialSwitchComponent, MaterialTextareaComponent, MaterialDatepickerComponent as ɵa, MaterialTabGroupComponent as ɵb, MaterialStepperComponent as ɵc };
//# sourceMappingURL=angular-dynaform-material.js.map
