import { DynamicFormControlComponentBase, DynamicFormControlComponent, DynamicFormErrorComponent, DynamicFormFormControlComponent, DynamicForm, DynamicFormService, ControlType, DynamicFormModule } from '@angular-dynaform/core';
import { CommonModule } from '@angular/common';
import { Component, ElementRef, ViewChild, EventEmitter, NgModule, Optional, SkipSelf } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { MatButtonModule, MatCheckboxModule, MatInputModule, MatRadioModule, MatSelectModule, MatSliderModule, MatSlideToggleModule, MatNativeDateModule, MatDatepickerModule, MatTabsModule, MatStepperModule, MatIconModule } from '@angular/material';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { __extends } from 'tslib';
import { map, takeUntil } from 'rxjs/operators';
import { Subject } from 'rxjs';

var MaterialArrayComponent = (function (_super) {
    __extends(MaterialArrayComponent, _super);
    function MaterialArrayComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialArrayComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-array-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <fieldset [id]=\"model.id\" [ngClass]=\"model.css.control\" adfHTMLDomElement>\n        <legend\n          *ngIf=\"model.local.label\"\n          [ngClass]=\"model.css.label\"\n          [innerHTML]=\"model.local.label\"\n        ></legend>\n        <ng-container *ngIf=\"model.header\">\n          <div [ngClass]=\"model.header?.css.content\">\n            <ng-container\n              *ngFor=\"let item of model.header?.items\"\n              adfControlComponent\n              [model]=\"item\"\n            ></ng-container>\n          </div>\n        </ng-container>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <div [formArrayName]=\"model.key\" [ngClass]=\"model.css.content\">\n          <ng-container *ngFor=\"let arrayItem of model.items; let i = index\" [formGroupName]=\"i\">\n            <div [ngClass]=\"arrayItem.css.content\">\n              <ng-container\n                *ngFor=\"let item of arrayItem.items\"\n                adfControlComponent\n                [model]=\"item\"\n              ></ng-container>\n            </div>\n          </ng-container>\n        </div>\n        <ng-container *ngIf=\"model.footer\">\n          <div [ngClass]=\"model.footer?.css.content\">\n            <ng-container\n              *ngFor=\"let item of model.footer?.items\"\n              adfControlComponent\n              [model]=\"item\"\n            ></ng-container>\n          </div>\n        </ng-container>\n      </fieldset>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialArrayComponent }]
                }] }
    ];
    return MaterialArrayComponent;
}(DynamicFormControlComponent));

var MaterialButtonComponent = (function (_super) {
    __extends(MaterialButtonComponent, _super);
    function MaterialButtonComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialButtonComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        _super.prototype.ngAfterViewInit.call(this);
        setTimeout((function () {
            if (_this.model.ngControl.disabled) {
                _this.model.ngControl.enable({ emitEvent: false });
                _this.model.ngControl.disable();
            }
            else {
                _this.model.ngControl.disable({ emitEvent: false });
                _this.model.ngControl.enable();
            }
        }));
    };
    MaterialButtonComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-button-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <button\n        mat-raised-button\n        [formControlName]=\"model.key\"\n        [id]=\"model.id\"\n        [ngClass]=\"model.css.control\"\n        [type]=\"buttonType\"\n        adfHTMLDomElement\n        ngDefaultControl\n      >\n        <span [ngClass]=\"model.css.control\" [innerHTML]=\"model.local.label\"></span>\n      </button>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialButtonComponent }]
                }] }
    ];
    return MaterialButtonComponent;
}(DynamicFormControlComponent));

var MaterialCheckboxComponent = (function (_super) {
    __extends(MaterialCheckboxComponent, _super);
    function MaterialCheckboxComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialCheckboxComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-checkbox-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <mat-checkbox\n        [formControlName]=\"model.key\"\n        [id]=\"model.id\"\n        [ngClass]=\"model.css.control\"\n        adfHTMLDomElement\n        [required]=\"options.required ? '' : null\"\n      >\n        {{ model.local.label }}\n      </mat-checkbox>\n      <adf-error-container [model]=\"model\"></adf-error-container>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialCheckboxComponent }]
                }] }
    ];
    return MaterialCheckboxComponent;
}(DynamicFormControlComponent));

var MaterialDatepickerComponent = (function (_super) {
    __extends(MaterialDatepickerComponent, _super);
    function MaterialDatepickerComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialDatepickerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-datepicker-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-form-field [ngClass]=\"model.css.control\">\n        <input\n          matInput\n          [formControlName]=\"model.key\"\n          [id]=\"model.id\"\n          type=\"text\"\n          [readonly]=\"options.readOnly\"\n          [maxlength]=\"options.maxLength\"\n          [placeholder]=\"model.local.placeholder\"\n          [ngClass]=\"model.css.control\"\n          adfHTMLDomElement\n          [matDatepicker]=\"myDatepicker\"\n          [required]=\"options.required ? '' : null\"\n        />\n        <mat-datepicker-toggle matSuffix [for]=\"myDatepicker\"></mat-datepicker-toggle>\n        <mat-datepicker #myDatepicker></mat-datepicker>\n        <span matPrefix *ngIf=\"options.icon\">\n          <mat-icon>{{ options.icon }}</mat-icon>\n        </span>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <mat-hint [innerHTML]=\"model.local.hint\"></mat-hint>\n      </mat-form-field>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [
                        { provide: DynamicFormControlComponentBase, useExisting: MaterialDatepickerComponent },
                    ]
                }] }
    ];
    return MaterialDatepickerComponent;
}(DynamicFormControlComponent));

var MaterialDivisionComponent = (function (_super) {
    __extends(MaterialDivisionComponent, _super);
    function MaterialDivisionComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialDivisionComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-division-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <div [ngClass]=\"model.css.control\" adfHTMLDomElement>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <div [ngClass]=\"model.css.content\">\n          <ng-container\n            *ngFor=\"let item of model.items\"\n            adfControlComponent\n            [model]=\"item\"\n          ></ng-container>\n        </div>\n      </div>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialDivisionComponent }]
                }] }
    ];
    return MaterialDivisionComponent;
}(DynamicFormControlComponent));

var MaterialErrorComponent = (function (_super) {
    __extends(MaterialErrorComponent, _super);
    function MaterialErrorComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialErrorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-error-component',
                    template: "\n    <mat-error [ngClass]=\"model.css.error\" [innerHTML]=\"error?.message\"></mat-error>\n  ",
                    inputs: ['model', 'error'],
                    host: { class: 'mat-input-error' },
                    providers: [{ provide: DynamicFormErrorComponent, useExisting: MaterialErrorComponent }]
                }] }
    ];
    return MaterialErrorComponent;
}(DynamicFormErrorComponent));

var MaterialFieldsetComponent = (function (_super) {
    __extends(MaterialFieldsetComponent, _super);
    function MaterialFieldsetComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialFieldsetComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-fieldset-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <fieldset [id]=\"model.id\" [ngClass]=\"model.css.control\" adfHTMLDomElement>\n        <legend\n          *ngIf=\"model.local.label\"\n          [ngClass]=\"model.css.label\"\n          [innerHTML]=\"model.local.label\"\n        ></legend>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <div [ngClass]=\"model.css.content\">\n          <ng-container\n            *ngFor=\"let item of model.items\"\n            adfControlComponent\n            [model]=\"item\"\n          ></ng-container>\n        </div>\n      </fieldset>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialFieldsetComponent }]
                }] }
    ];
    return MaterialFieldsetComponent;
}(DynamicFormControlComponent));

var MaterialFormComponent = (function (_super) {
    __extends(MaterialFormComponent, _super);
    function MaterialFormComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialFormComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-form-component',
                    template: "\n    <div>\n      <form\n        [formGroup]=\"model.ngControl\"\n        [id]=\"model.id\"\n        [ngClass]=\"model.css.control\"\n        (ngSubmit)=\"onSubmit($event)\"\n        (reset)=\"onReset($event)\"\n        adfHTMLDomElement\n        novalidate\n      >\n        <div [ngClass]=\"model.css.content\">\n          <ng-container\n            *ngFor=\"let item of model.items\"\n            adfControlComponent\n            [model]=\"item\"\n          ></ng-container>\n        </div>\n      </form>\n    </div>\n  ",
                    inputs: ['model'],
                    outputs: ['submit', 'reset'],
                    providers: [
                        {
                            provide: DynamicFormControlComponentBase,
                            useExisting: MaterialFormComponent,
                        },
                        { provide: DynamicFormFormControlComponent, useExisting: MaterialFormComponent },
                    ]
                }] }
    ];
    return MaterialFormComponent;
}(DynamicFormFormControlComponent));

var MaterialInputComponent = (function (_super) {
    __extends(MaterialInputComponent, _super);
    function MaterialInputComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialInputComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-input-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-form-field [ngClass]=\"model.css.control\">\n        <input\n          matInput\n          [formControlName]=\"model.key\"\n          [id]=\"model.id\"\n          [type]=\"options.inputType || 'text'\"\n          [readonly]=\"options.readOnly\"\n          [attr.autocomplete]=\"model.autoComplete\"\n          [placeholder]=\"model.local.placeholder\"\n          [ngClass]=\"model.css.control\"\n          adfHTMLDomElement\n          [required]=\"options.required ? '' : null\"\n          [attr.min]=\"options.min\"\n          [attr.max]=\"options.max\"\n          [maxlength]=\"options.maxLength\"\n        />\n        <span matPrefix *ngIf=\"options.icon\">\n          <mat-icon>{{ options.icon }}</mat-icon>\n        </span>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <mat-hint [innerHTML]=\"model.local.hint\"></mat-hint>\n      </mat-form-field>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialInputComponent }]
                }] }
    ];
    return MaterialInputComponent;
}(DynamicFormControlComponent));

var MaterialRadioGroupComponent = (function (_super) {
    __extends(MaterialRadioGroupComponent, _super);
    function MaterialRadioGroupComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialRadioGroupComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-radiogroup-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-radio-group\n        [id]=\"model.id\"\n        [formControlName]=\"model.key\"\n        ngDefaultControl\n        adfHTMLDomElement\n        [ngClass]=\"model.css.control\"\n        [required]=\"options.required ? '' : null\"\n      >\n        <mat-radio-button *ngFor=\"let opt of model.local.valueOptions\" [value]=\"opt.value\">\n          <span [innerHTML]=\"opt.label\"></span>\n        </mat-radio-button>\n      </mat-radio-group>\n      <adf-error-container [model]=\"model\"></adf-error-container>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [
                        { provide: DynamicFormControlComponentBase, useExisting: MaterialRadioGroupComponent },
                    ]
                }] }
    ];
    return MaterialRadioGroupComponent;
}(DynamicFormControlComponent));

var MaterialSelectComponent = (function (_super) {
    __extends(MaterialSelectComponent, _super);
    function MaterialSelectComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialSelectComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-select-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-form-field [ngClass]=\"model.css.control\">\n        <mat-select\n          [formControlName]=\"model.key\"\n          [id]=\"model.id\"\n          [placeholder]=\"model.local.placeholder\"\n          [multiple]=\"options.multiple\"\n          [ngClass]=\"model.css.control\"\n          adfHTMLDomElement\n          [required]=\"options.required ? '' : null\"\n        >\n          <mat-option *ngFor=\"let opt of model.local.valueOptions\" [value]=\"opt.value\">\n            <span [innerHTML]=\"opt.label\"></span>\n          </mat-option>\n        </mat-select>\n        <span matPrefix *ngIf=\"options.icon\">\n          <mat-icon>{{ options.icon }}</mat-icon>\n        </span>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <mat-hint [innerHTML]=\"model.local.hint\"></mat-hint>\n      </mat-form-field>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialSelectComponent }]
                }] }
    ];
    return MaterialSelectComponent;
}(DynamicFormControlComponent));

var MaterialSeparatorComponent = (function (_super) {
    __extends(MaterialSeparatorComponent, _super);
    function MaterialSeparatorComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialSeparatorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-separator-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <span [ngClass]=\"model.css.control\" [innerHTML]=\"model.local.label\"></span>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [
                        { provide: DynamicFormControlComponentBase, useExisting: MaterialSeparatorComponent },
                    ]
                }] }
    ];
    return MaterialSeparatorComponent;
}(DynamicFormControlComponent));

var MaterialSliderComponent = (function (_super) {
    __extends(MaterialSliderComponent, _super);
    function MaterialSliderComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialSliderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-slider-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-slider\n        [formControlName]=\"model.key\"\n        [id]=\"model.id\"\n        [step]=\"options.step\"\n        [ngClass]=\"model.css.control\"\n        adfHTMLDomElement\n        [required]=\"options.required ? '' : null\"\n        [attr.min]=\"options.min\"\n        [attr.max]=\"options.max\"\n      ></mat-slider>\n      <adf-error-container [model]=\"model\"></adf-error-container>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialSliderComponent }]
                }] }
    ];
    return MaterialSliderComponent;
}(DynamicFormControlComponent));

var MaterialStepperComponent = (function (_super) {
    __extends(MaterialStepperComponent, _super);
    function MaterialStepperComponent(form, dynamicFormService, elRef) {
        return _super.call(this, form, dynamicFormService, elRef) || this;
    }
    MaterialStepperComponent.prototype.ngOnInit = function () {
        this.stepper = new MatStepperWrapper(this.matStepper);
        if (!this.form.stepper) {
            this.form.stepper = this.stepper;
        }
        _super.prototype.ngOnInit.call(this);
    };
    MaterialStepperComponent.prototype.ngAfterViewInit = function () {
        (((this.stepper))).matStepper = this.matStepper;
        _super.prototype.ngAfterViewInit.call(this);
    };
    MaterialStepperComponent.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
        if (this.stepper) {
            if (this.form.stepper === this.stepper) {
                this.form.stepper = undefined;
            }
            (((this.stepper))).matStepper = undefined;
        }
    };
    MaterialStepperComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-stepper-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <div [ngClass]=\"model.css.control\" adfHTMLDomElement>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n\n        <!--ng-template #steps>\n            <mat-step *ngFor=\"let item of model.items; let i=index\"\n              [stepControl]=\"item.ngSubsetControl ? item.ngSubsetControl : item.ngControl\"\n              [optional]=\"options.matStepOptional\" [editable]=\"options.matStepEditable\" [completed]=\"options.matStepCompleted\"\n            >\n              <ng-template matStepLabel>{{item.local.label}}</ng-template>\n              <ng-template adfControlComponent [model]=\"item\"></ng-template>\n            </mat-step>\n        </ng-template-->\n\n        <ng-container *ngIf=\"options.matStepperVertical; else horizontalStepper\">\n          <mat-vertical-stepper\n            [ngClass]=\"model.css.content\"\n            [linear]=\"options.matStepperLinear === undefined ? false : options.matStepperLinear\"\n            #stepper\n          >\n            <!--ng-container *ngTemplateOutlet=\"steps\"></ng-container-->\n            <mat-step\n              *ngFor=\"let item of model.items; let i = index\"\n              [stepControl]=\"item.ngSubsetControl ? item.ngSubsetControl : item.ngControl\"\n              [editable]=\"options.matStepEditable === undefined ? true : options.matStepEditable\"\n              [optional]=\"options.matStepOptional\"\n              [completed]=\"options.matStepCompleted\"\n            >\n              <ng-template matStepLabel>{{ item.local.label }}</ng-template>\n              <ng-template adfControlComponent [model]=\"item\"></ng-template>\n            </mat-step>\n          </mat-vertical-stepper>\n        </ng-container>\n\n        <ng-template #horizontalStepper>\n          <mat-horizontal-stepper\n            [ngClass]=\"model.css.content\"\n            [linear]=\"options.matStepperLinear === undefined ? false : options.matStepperLinear\"\n            #stepper\n          >\n            <!--ng-container *ngTemplateOutlet=\"steps\"></ng-container-->\n            <mat-step\n              *ngFor=\"let item of model.items; let i = index\"\n              [stepControl]=\"item.ngSubsetControl ? item.ngSubsetControl : item.ngControl\"\n              [editable]=\"options.matStepEditable === undefined ? true : options.matStepEditable\"\n              [optional]=\"options.matStepOptional\"\n              [completed]=\"options.matStepCompleted\"\n            >\n              <ng-template matStepLabel>{{ item.local.label }}</ng-template>\n              <ng-template adfControlComponent [model]=\"item\"></ng-template>\n            </mat-step>\n          </mat-horizontal-stepper>\n        </ng-template>\n      </div>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialStepperComponent }]
                }] }
    ];
    MaterialStepperComponent.ctorParameters = function () { return [
        { type: DynamicForm },
        { type: DynamicFormService },
        { type: ElementRef }
    ]; };
    MaterialStepperComponent.propDecorators = {
        matStepper: [{ type: ViewChild, args: ['stepper', { static: true },] }]
    };
    return MaterialStepperComponent;
}(DynamicFormControlComponent));
var MatStepperWrapper = (function () {
    function MatStepperWrapper(matStepper) {
        this._selectionChange = new EventEmitter();
        this.matStepper = matStepper;
    }
    Object.defineProperty(MatStepperWrapper.prototype, "matStepper", {
        get: function () {
            return this._matStepper;
        },
        set: function (matStepper) {
            this.changeStepper(matStepper);
        },
        enumerable: true,
        configurable: true
    });
    MatStepperWrapper.prototype.prev = function () {
        if (this.matStepper) {
            this.matStepper.previous();
        }
    };
    MatStepperWrapper.prototype.next = function () {
        if (this.matStepper) {
            this.matStepper.next();
        }
    };
    MatStepperWrapper.prototype.selectionChange = function () {
        return this._selectionChange;
    };
    MatStepperWrapper.prototype.length = function () {
        return this.matStepper && this.matStepper._steps ? this.matStepper._steps.length : 0;
    };
    MatStepperWrapper.prototype.changeStepper = function (matStepper) {
        var _this = this;
        if (this._matStepper === matStepper) {
            return;
        }
        if (this._matStepper && this.unsubscribe) {
            this.unsubscribe.next();
            this.unsubscribe.complete();
        }
        if (matStepper) {
            this.unsubscribe = new Subject();
            matStepper.selectionChange
                .pipe(map((function (sc) { return sc.selectedIndex; })))
                .pipe(takeUntil(this.unsubscribe))
                .subscribe((function (currIndex) { return _this._selectionChange.emit(currIndex); }));
        }
        this._matStepper = matStepper;
    };
    return MatStepperWrapper;
}());

var MaterialSwitchComponent = (function (_super) {
    __extends(MaterialSwitchComponent, _super);
    function MaterialSwitchComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialSwitchComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-switch-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-slide-toggle\n        [formControlName]=\"model.key\"\n        [id]=\"model.id\"\n        [ngClass]=\"model.css.control\"\n        adfHTMLDomElement\n        [required]=\"options.required ? '' : null\"\n      ></mat-slide-toggle>\n      <adf-error-container [model]=\"model\"></adf-error-container>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialSwitchComponent }]
                }] }
    ];
    return MaterialSwitchComponent;
}(DynamicFormControlComponent));

var MaterialTabGroupComponent = (function (_super) {
    __extends(MaterialTabGroupComponent, _super);
    function MaterialTabGroupComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialTabGroupComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-tab-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <div [ngClass]=\"model.css.control\" adfHTMLDomElement>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <mat-tab-group\n          adfHTMLDomElement\n          [ngClass]=\"model.css.content\"\n          [dynamicHeight]=\"options.matTabGroupDynamicHeight\"\n        >\n          <mat-tab *ngFor=\"let item of model.items\">\n            <ng-template mat-tab-label>{{ item.local.label }}</ng-template>\n            <ng-template adfControlComponent [model]=\"item\"></ng-template>\n          </mat-tab>\n        </mat-tab-group>\n      </div>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialTabGroupComponent }]
                }] }
    ];
    return MaterialTabGroupComponent;
}(DynamicFormControlComponent));

var MaterialTextareaComponent = (function (_super) {
    __extends(MaterialTextareaComponent, _super);
    function MaterialTextareaComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaterialTextareaComponent.decorators = [
        { type: Component, args: [{
                    selector: 'adf-material-textarea-component',
                    template: "\n    <div [formGroup]=\"model.ngGroup\" [hidden]=\"model.hidden\">\n      <label\n        *ngIf=\"model.local.label\"\n        [attr.for]=\"model.id\"\n        class=\"adf-front-label\"\n        [ngClass]=\"model.css.label\"\n        [innerHTML]=\"model.local.label\"\n      ></label>\n      <mat-form-field [ngClass]=\"model.css.control\">\n        <textarea\n          matInput\n          [formControlName]=\"model.key\"\n          [id]=\"model.id\"\n          [readonly]=\"options.readOnly\"\n          [wrap]=\"options.wrap\"\n          [cols]=\"options.cols\"\n          [rows]=\"options.rows\"\n          [placeholder]=\"model.local.placeholder\"\n          [ngClass]=\"model.css.control\"\n          adfHTMLDomElement\n          [required]=\"options.required ? '' : null\"\n          [attr.min]=\"options.min\"\n          [attr.max]=\"options.max\"\n          [maxlength]=\"options.maxLength\"\n        ></textarea>\n        <span matPrefix *ngIf=\"options.icon\">\n          <mat-icon>{{ options.icon }}</mat-icon>\n        </span>\n        <adf-error-container [model]=\"model\"></adf-error-container>\n        <mat-hint [innerHTML]=\"model.local.hint\"></mat-hint>\n      </mat-form-field>\n    </div>\n  ",
                    inputs: ['model'],
                    providers: [{ provide: DynamicFormControlComponentBase, useExisting: MaterialTextareaComponent }]
                }] }
    ];
    return MaterialTextareaComponent;
}(DynamicFormControlComponent));

var MaterialControlType = {
    CONTROL_UNKNOWN: 'mat:unknown',
    CONTROL_DIVISION: 'mat:division',
    CONTROL_FIELDSET: 'mat:fieldset',
    CONTROL_TABGROUP: 'mat:tabgroup',
    CONTROL_STEPPER: 'mat:stepper',
    CONTROL_ARRAY: 'mat:array',
    CONTROL_CHECKBOX: 'mat:checkbox',
    CONTROL_INPUT: 'mat:input',
    CONTROL_RADIOGROUP: 'mat:radiogroup',
    CONTROL_SELECT: 'mat:select',
    CONTROL_SLIDER: 'mat:slider',
    CONTROL_SWITCH: 'mat:switch',
    CONTROL_TEXTAREA: 'mat:textarea',
    CONTROL_DATEPICKER: 'mat:datepicker',
    CONTROL_TIMEPICKER: 'mat:timepicker',
    CONTROL_LISTPICKER: 'mat:listpicker',
    CONTROL_UPLOAD: 'mat:upload',
    CONTROL_BUTTON: 'mat:button',
    CONTROL_SEPARATOR: 'mat:separator',
};

var entryComponents = [
    MaterialFormComponent,
    MaterialErrorComponent,
    MaterialArrayComponent,
    MaterialDivisionComponent,
    MaterialFieldsetComponent,
    MaterialButtonComponent,
    MaterialCheckboxComponent,
    MaterialInputComponent,
    MaterialRadioGroupComponent,
    MaterialSelectComponent,
    MaterialSeparatorComponent,
    MaterialSliderComponent,
    MaterialSwitchComponent,
    MaterialTextareaComponent,
    MaterialDatepickerComponent,
    MaterialTabGroupComponent,
    MaterialStepperComponent,
];
var moduleDeclarations = entryComponents;
var DynamicMaterialFormModule = (function () {
    function DynamicMaterialFormModule(dynamicFormService, parentModule) {
        this.dynamicFormService = dynamicFormService;
        if (parentModule) {
            return;
        }
        this.dynamicFormService.setFormControlComponent(MaterialFormComponent, true);
        this.dynamicFormService.setErrorComponent(MaterialErrorComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_ARRAY, MaterialArrayComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_FIELDSET, MaterialFieldsetComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_DIVISION, MaterialDivisionComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_TABGROUP, MaterialTabGroupComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_STEPPER, MaterialStepperComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_BUTTON, MaterialButtonComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SEPARATOR, MaterialSeparatorComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_CHECKBOX, MaterialCheckboxComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_DATEPICKER, MaterialDatepickerComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_INPUT, MaterialInputComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_RADIOGROUP, MaterialRadioGroupComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SELECT, MaterialSelectComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SLIDER, MaterialSliderComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_SWITCH, MaterialSwitchComponent, true);
        this.dynamicFormService.setControlComponent(ControlType.CONTROL_TEXTAREA, MaterialTextareaComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_ARRAY, MaterialArrayComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_FIELDSET, MaterialFieldsetComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_DIVISION, MaterialDivisionComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_TABGROUP, MaterialTabGroupComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_STEPPER, MaterialStepperComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_BUTTON, MaterialButtonComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SEPARATOR, MaterialSeparatorComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_CHECKBOX, MaterialCheckboxComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_DATEPICKER, MaterialDatepickerComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_INPUT, MaterialInputComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_RADIOGROUP, MaterialRadioGroupComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SELECT, MaterialSelectComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SLIDER, MaterialSliderComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_SWITCH, MaterialSwitchComponent, true);
        this.dynamicFormService.setControlComponent(MaterialControlType.CONTROL_TEXTAREA, MaterialTextareaComponent, true);
    }
    DynamicMaterialFormModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        DynamicFormModule,
                        BrowserAnimationsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatInputModule,
                        MatRadioModule,
                        MatSelectModule,
                        MatSliderModule,
                        MatSlideToggleModule,
                        MatNativeDateModule,
                        MatDatepickerModule,
                        MatTabsModule,
                        MatStepperModule,
                        MatIconModule,
                    ],
                    declarations: [moduleDeclarations],
                    entryComponents: entryComponents,
                    exports: [DynamicFormModule, entryComponents],
                },] }
    ];
    DynamicMaterialFormModule.ctorParameters = function () { return [
        { type: DynamicFormService },
        { type: DynamicMaterialFormModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    return DynamicMaterialFormModule;
}());

export { DynamicMaterialFormModule, MaterialArrayComponent, MaterialButtonComponent, MaterialCheckboxComponent, MaterialControlType, MaterialDivisionComponent, MaterialErrorComponent, MaterialFieldsetComponent, MaterialFormComponent, MaterialInputComponent, MaterialRadioGroupComponent, MaterialSelectComponent, MaterialSeparatorComponent, MaterialSliderComponent, MaterialSwitchComponent, MaterialTextareaComponent, MaterialDatepickerComponent as ɵa, MaterialTabGroupComponent as ɵb, MaterialStepperComponent as ɵc };
//# sourceMappingURL=angular-dynaform-material.js.map
